Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to IAM Access Analyzer.
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

Actions, Resources, and Condition Keys for IAM Access Analyzer - AWS Identity and Access Management

# Actions, Resources, and Condition Keys for IAM Access Analyzer

IAM Access Analyzer (service prefix: `access-analyzer` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions Defined by IAM Access Analyzer
- Resource Types Defined by IAM Access Analyzer
- Condition Keys for IAM Access Analyzer

## Actions Defined by IAM Access Analyzer

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource Types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The Actions Table .

Actions | Description | Access Level | Resource Types (*required) | Condition Keys | Dependent Actions
--- | --- | --- | --- | --- | ---
CreateAnalyzer | Grants permission to create an analyzer. | Write | Analyzer* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateArchiveRule | Grants permission to create an archive rule for the specified analyzer. | Write | Analyzer* |  |
ArchiveRule* |  |
DeleteAnalyzer | Grants permission to delete the specified analyzer. | Write | Analyzer* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
DeleteArchiveRule | Grants permission to delete archive rules for the specified analyzer. | Write | Analyzer* |  |
ArchiveRule* |  |
GetAnalyzedResource | Grants permission to retrieve information about an analyzed resource. | Read |  |  |
GetAnalyzer | Grants permission to retrieve information about analyzers. | Read | Analyzer* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
GetArchiveRule | Grants permission to retrieve information about archive rules for the specified analyzer. | Read | Analyzer* |  |
ArchiveRule* |  |
GetFinding | Grants permission to retrieve findings. | Read |  |  |
ListAnalyzedResources | Grants permission to retrieve a list of resources that have been analyzed. | Read |  |  |
ListAnalyzers | Grants permission to retrieves a list of analyzers. | List |  |  |
ListArchiveRules | Grants permission to retrieve a list of archive rules from an analyzer. | List | Analyzer* |  |
ListFindings | Grants permission to retrieve a list of findings from an analyzer. | Read |  |  |
ListTagsForResource | Grants permission to retrieve a list of tags applied to a resource. | Read | Analyzer |  |
StartResourceScan | Grants permission to start a scan of the policies applied to a resource. | Write |  |  |
TagResource | Grants permission to add a tag to a resource. | Tagging | Analyzer |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UntagResource | Grants permission to remove a tag from a resource. | Tagging | Analyzer |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UpdateArchiveRule | Grants permission to modify an archive rule. | Write | Analyzer* |  |
ArchiveRule* |  |
UpdateFindings | Grants permission to modify findings. | Write |  |  |

## Resource Types Defined by IAM Access Analyzer

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The Resource Types Table .

Resource Types | ARN | Condition Keys
--- | --- | ---
Analyzer | `arn:$ { Partition}:access-analyzer:$ { Region}:$ { Account}:analyzer/$ { analyzerName}` | aws:ResourceTag/${TagKey}
ArchiveRule | `arn:$ { Partition}:access-analyzer:$ { Region}:$ { Account}:analyzer/$ { analyzerName}/archive-rule/$ { ruleName}` |

## Condition Keys for IAM Access Analyzer

IAM Access Analyzer defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The Condition Keys Table .

To view the global condition keys that are available to all services, see Available Global Condition Keys in the IAM Policy Reference .

Condition Keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters actions based on the presence of tag key-value pairs in the request | String
aws:ResourceTag/${TagKey} | Filters actions based on tag key-value pairs attached to the resource | String
aws:TagKeys | Filters actions based on the presence of tag keys in the request | String

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.